import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface CloudSchedulerJobConfig extends cdktf.TerraformMetaArguments {
    /**
     * The deadline for job attempts.
     *
     * If the request handler does not respond by this deadline then the request is
     * cancelled and the attempt is marked as a DEADLINE_EXCEEDED failure. The failed attempt can be viewed in
     * execution logs. Cloud Scheduler will retry the job according to the RetryConfig.
     * The allowed duration for this deadline is:
     * For HTTP targets, between 15 seconds and 30 minutes.
     * For App Engine HTTP targets, between 15 seconds and 24 hours.
     * **Note**: For PubSub targets, this field is ignored - setting it will introduce an unresolvable diff.
     * A duration in seconds with up to nine fractional digits, terminated by 's'. Example: "3.5s"
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#attempt_deadline CloudSchedulerJob#attempt_deadline}
     *
     * @stability stable
     */
    readonly attemptDeadline?: string;
    /**
     * A human-readable description for the job.  This string must not contain more than 500 characters.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#description CloudSchedulerJob#description}
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * The name of the job.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#name CloudSchedulerJob#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#project CloudSchedulerJob#project}.
     *
     * @stability stable
     */
    readonly project?: string;
    /**
     * Region where the scheduler job resides. If it is not provided, Terraform will use the provider default.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#region CloudSchedulerJob#region}
     *
     * @stability stable
     */
    readonly region?: string;
    /**
     * Describes the schedule on which the job will be executed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#schedule CloudSchedulerJob#schedule}
     *
     * @stability stable
     */
    readonly schedule?: string;
    /**
     * Specifies the time zone to be used in interpreting schedule.
     *
     * The value of this field must be a time zone name from the tz database.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#time_zone CloudSchedulerJob#time_zone}
     *
     * @stability stable
     */
    readonly timeZone?: string;
    /**
     * app_engine_http_target block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#app_engine_http_target CloudSchedulerJob#app_engine_http_target}
     *
     * @stability stable
     */
    readonly appEngineHttpTarget?: CloudSchedulerJobAppEngineHttpTarget[];
    /**
     * http_target block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#http_target CloudSchedulerJob#http_target}
     *
     * @stability stable
     */
    readonly httpTarget?: CloudSchedulerJobHttpTarget[];
    /**
     * pubsub_target block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#pubsub_target CloudSchedulerJob#pubsub_target}
     *
     * @stability stable
     */
    readonly pubsubTarget?: CloudSchedulerJobPubsubTarget[];
    /**
     * retry_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#retry_config CloudSchedulerJob#retry_config}
     *
     * @stability stable
     */
    readonly retryConfig?: CloudSchedulerJobRetryConfig[];
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#timeouts CloudSchedulerJob#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: CloudSchedulerJobTimeouts;
}
/**
 * @stability stable
 */
export interface CloudSchedulerJobAppEngineHttpTargetAppEngineRouting {
    /**
     * App instance. By default, the job is sent to an instance which is available when the job is attempted.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#instance CloudSchedulerJob#instance}
     *
     * @stability stable
     */
    readonly instance?: string;
    /**
     * App service.
     *
     * By default, the job is sent to the service which is the default service when the job is attempted.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#service CloudSchedulerJob#service}
     *
     * @stability stable
     */
    readonly service?: string;
    /**
     * App version.
     *
     * By default, the job is sent to the version which is the default version when the job is attempted.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#version CloudSchedulerJob#version}
     *
     * @stability stable
     */
    readonly version?: string;
}
/**
 * @stability stable
 */
export interface CloudSchedulerJobAppEngineHttpTarget {
    /**
     * HTTP request body.
     *
     * A request body is allowed only if the HTTP method is POST or PUT.
     * It will result in invalid argument error to set a body on a job with an incompatible HttpMethod.
     *
     * A base64-encoded string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#body CloudSchedulerJob#body}
     *
     * @stability stable
     */
    readonly body?: string;
    /**
     * HTTP request headers.
     *
     * This map contains the header field names and values.
     * Headers can be set when the job is created.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#headers CloudSchedulerJob#headers}
     *
     * @stability stable
     */
    readonly headers?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Which HTTP method to use for the request.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#http_method CloudSchedulerJob#http_method}
     *
     * @stability stable
     */
    readonly httpMethod?: string;
    /**
     * The relative URI.
     *
     * The relative URL must begin with "/" and must be a valid HTTP relative URL.
     * It can contain a path, query string arguments, and \# fragments.
     * If the relative URL is empty, then the root path "/" will be used.
     * No spaces are allowed, and the maximum length allowed is 2083 characters
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#relative_uri CloudSchedulerJob#relative_uri}
     *
     * @stability stable
     */
    readonly relativeUri: string;
    /**
     * app_engine_routing block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#app_engine_routing CloudSchedulerJob#app_engine_routing}
     *
     * @stability stable
     */
    readonly appEngineRouting?: CloudSchedulerJobAppEngineHttpTargetAppEngineRouting[];
}
/**
 * @stability stable
 */
export interface CloudSchedulerJobHttpTargetOauthToken {
    /**
     * OAuth scope to be used for generating OAuth access token. If not specified, "https://www.googleapis.com/auth/cloud-platform" will be used.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#scope CloudSchedulerJob#scope}
     *
     * @stability stable
     */
    readonly scope?: string;
    /**
     * Service account email to be used for generating OAuth token.
     *
     * The service account must be within the same project as the job.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#service_account_email CloudSchedulerJob#service_account_email}
     *
     * @stability stable
     */
    readonly serviceAccountEmail: string;
}
/**
 * @stability stable
 */
export interface CloudSchedulerJobHttpTargetOidcToken {
    /**
     * Audience to be used when generating OIDC token. If not specified, the URI specified in target will be used.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#audience CloudSchedulerJob#audience}
     *
     * @stability stable
     */
    readonly audience?: string;
    /**
     * Service account email to be used for generating OAuth token.
     *
     * The service account must be within the same project as the job.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#service_account_email CloudSchedulerJob#service_account_email}
     *
     * @stability stable
     */
    readonly serviceAccountEmail: string;
}
/**
 * @stability stable
 */
export interface CloudSchedulerJobHttpTarget {
    /**
     * HTTP request body.
     *
     * A request body is allowed only if the HTTP method is POST, PUT, or PATCH.
     * It is an error to set body on a job with an incompatible HttpMethod.
     *
     * A base64-encoded string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#body CloudSchedulerJob#body}
     *
     * @stability stable
     */
    readonly body?: string;
    /**
     * This map contains the header field names and values.
     *
     * Repeated headers are not supported, but a header value can contain commas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#headers CloudSchedulerJob#headers}
     *
     * @stability stable
     */
    readonly headers?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Which HTTP method to use for the request.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#http_method CloudSchedulerJob#http_method}
     *
     * @stability stable
     */
    readonly httpMethod?: string;
    /**
     * The full URI path that the request will be sent to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#uri CloudSchedulerJob#uri}
     *
     * @stability stable
     */
    readonly uri: string;
    /**
     * oauth_token block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#oauth_token CloudSchedulerJob#oauth_token}
     *
     * @stability stable
     */
    readonly oauthToken?: CloudSchedulerJobHttpTargetOauthToken[];
    /**
     * oidc_token block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#oidc_token CloudSchedulerJob#oidc_token}
     *
     * @stability stable
     */
    readonly oidcToken?: CloudSchedulerJobHttpTargetOidcToken[];
}
/**
 * @stability stable
 */
export interface CloudSchedulerJobPubsubTarget {
    /**
     * Attributes for PubsubMessage. Pubsub message must contain either non-empty data, or at least one attribute.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#attributes CloudSchedulerJob#attributes}
     *
     * @stability stable
     */
    readonly attributes?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * The message payload for PubsubMessage. Pubsub message must contain either non-empty data, or at least one attribute.
     *
     * A base64-encoded string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#data CloudSchedulerJob#data}
     *
     * @stability stable
     */
    readonly data?: string;
    /**
     * The full resource name for the Cloud Pub/Sub topic to which messages will be published when a job is delivered.
     *
     * ~>**NOTE:**
     * The topic name must be in the same format as required by PubSub's
     * PublishRequest.name, e.g. 'projects/my-project/topics/my-topic'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#topic_name CloudSchedulerJob#topic_name}
     *
     * @stability stable
     */
    readonly topicName: string;
}
/**
 * @stability stable
 */
export interface CloudSchedulerJobRetryConfig {
    /**
     * The maximum amount of time to wait before retrying a job after it fails.
     *
     * A duration in seconds with up to nine fractional digits, terminated by 's'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#max_backoff_duration CloudSchedulerJob#max_backoff_duration}
     *
     * @stability stable
     */
    readonly maxBackoffDuration?: string;
    /**
     * The time between retries will double maxDoublings times.
     *
     * A job's retry interval starts at minBackoffDuration,
     * then doubles maxDoublings times, then increases linearly,
     * and finally retries retries at intervals of maxBackoffDuration up to retryCount times.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#max_doublings CloudSchedulerJob#max_doublings}
     *
     * @stability stable
     */
    readonly maxDoublings?: number;
    /**
     * The time limit for retrying a failed job, measured from time when an execution was first attempted.
     *
     * If specified with retryCount, the job will be retried until both limits are reached.
     * A duration in seconds with up to nine fractional digits, terminated by 's'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#max_retry_duration CloudSchedulerJob#max_retry_duration}
     *
     * @stability stable
     */
    readonly maxRetryDuration?: string;
    /**
     * The minimum amount of time to wait before retrying a job after it fails.
     *
     * A duration in seconds with up to nine fractional digits, terminated by 's'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#min_backoff_duration CloudSchedulerJob#min_backoff_duration}
     *
     * @stability stable
     */
    readonly minBackoffDuration?: string;
    /**
     * The number of attempts that the system will make to run a  job using the exponential backoff procedure described by maxDoublings.
     *
     * Values greater than 5 and negative values are not allowed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#retry_count CloudSchedulerJob#retry_count}
     *
     * @stability stable
     */
    readonly retryCount?: number;
}
/**
 * @stability stable
 */
export interface CloudSchedulerJobTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#create CloudSchedulerJob#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#delete CloudSchedulerJob#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html#update CloudSchedulerJob#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html google_cloud_scheduler_job}.
 *
 * @stability stable
 */
export declare class CloudSchedulerJob extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/google/r/cloud_scheduler_job.html google_cloud_scheduler_job} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CloudSchedulerJobConfig);
    private _attemptDeadline?;
    /**
     * @stability stable
     */
    get attemptDeadline(): string;
    /**
     * @stability stable
     */
    set attemptDeadline(value: string);
    /**
     * @stability stable
     */
    resetAttemptDeadline(): void;
    /**
     * @stability stable
     */
    get attemptDeadlineInput(): string | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _region?;
    /**
     * @stability stable
     */
    get region(): string;
    /**
     * @stability stable
     */
    set region(value: string);
    /**
     * @stability stable
     */
    resetRegion(): void;
    /**
     * @stability stable
     */
    get regionInput(): string | undefined;
    private _schedule?;
    /**
     * @stability stable
     */
    get schedule(): string;
    /**
     * @stability stable
     */
    set schedule(value: string);
    /**
     * @stability stable
     */
    resetSchedule(): void;
    /**
     * @stability stable
     */
    get scheduleInput(): string | undefined;
    private _timeZone?;
    /**
     * @stability stable
     */
    get timeZone(): string;
    /**
     * @stability stable
     */
    set timeZone(value: string);
    /**
     * @stability stable
     */
    resetTimeZone(): void;
    /**
     * @stability stable
     */
    get timeZoneInput(): string | undefined;
    private _appEngineHttpTarget?;
    /**
     * @stability stable
     */
    get appEngineHttpTarget(): CloudSchedulerJobAppEngineHttpTarget[];
    /**
     * @stability stable
     */
    set appEngineHttpTarget(value: CloudSchedulerJobAppEngineHttpTarget[]);
    /**
     * @stability stable
     */
    resetAppEngineHttpTarget(): void;
    /**
     * @stability stable
     */
    get appEngineHttpTargetInput(): CloudSchedulerJobAppEngineHttpTarget[] | undefined;
    private _httpTarget?;
    /**
     * @stability stable
     */
    get httpTarget(): CloudSchedulerJobHttpTarget[];
    /**
     * @stability stable
     */
    set httpTarget(value: CloudSchedulerJobHttpTarget[]);
    /**
     * @stability stable
     */
    resetHttpTarget(): void;
    /**
     * @stability stable
     */
    get httpTargetInput(): CloudSchedulerJobHttpTarget[] | undefined;
    private _pubsubTarget?;
    /**
     * @stability stable
     */
    get pubsubTarget(): CloudSchedulerJobPubsubTarget[];
    /**
     * @stability stable
     */
    set pubsubTarget(value: CloudSchedulerJobPubsubTarget[]);
    /**
     * @stability stable
     */
    resetPubsubTarget(): void;
    /**
     * @stability stable
     */
    get pubsubTargetInput(): CloudSchedulerJobPubsubTarget[] | undefined;
    private _retryConfig?;
    /**
     * @stability stable
     */
    get retryConfig(): CloudSchedulerJobRetryConfig[];
    /**
     * @stability stable
     */
    set retryConfig(value: CloudSchedulerJobRetryConfig[]);
    /**
     * @stability stable
     */
    resetRetryConfig(): void;
    /**
     * @stability stable
     */
    get retryConfigInput(): CloudSchedulerJobRetryConfig[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): CloudSchedulerJobTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: CloudSchedulerJobTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): CloudSchedulerJobTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
