import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ComputeExternalVpnGatewayConfig extends cdktf.TerraformMetaArguments {
    /**
     * An optional description of this resource.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_external_vpn_gateway.html#description ComputeExternalVpnGateway#description}
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Name of the resource.
     *
     * Provided by the client when the resource is
     * created. The name must be 1-63 characters long, and comply with
     * RFC1035.  Specifically, the name must be 1-63 characters long and
     * match the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means
     * the first character must be a lowercase letter, and all following
     * characters must be a dash, lowercase letter, or digit, except the last
     * character, which cannot be a dash.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_external_vpn_gateway.html#name ComputeExternalVpnGateway#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_external_vpn_gateway.html#project ComputeExternalVpnGateway#project}.
     *
     * @stability stable
     */
    readonly project?: string;
    /**
     * Indicates the redundancy type of this external VPN gateway Possible values: ["FOUR_IPS_REDUNDANCY", "SINGLE_IP_INTERNALLY_REDUNDANT", "TWO_IPS_REDUNDANCY"].
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_external_vpn_gateway.html#redundancy_type ComputeExternalVpnGateway#redundancy_type}
     *
     * @stability stable
     */
    readonly redundancyType?: string;
    /**
     * interface block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_external_vpn_gateway.html#interface ComputeExternalVpnGateway#interface}
     *
     * @stability stable
     */
    readonly interface?: ComputeExternalVpnGatewayInterface[];
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_external_vpn_gateway.html#timeouts ComputeExternalVpnGateway#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: ComputeExternalVpnGatewayTimeouts;
}
/**
 * @stability stable
 */
export interface ComputeExternalVpnGatewayInterface {
    /**
     * The numeric ID for this interface.
     *
     * Allowed values are based on the redundancy type
     * of this external VPN gateway
     * '0 - SINGLE_IP_INTERNALLY_REDUNDANT'
     * '0, 1 - TWO_IPS_REDUNDANCY'
     * '0, 1, 2, 3 - FOUR_IPS_REDUNDANCY'
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_external_vpn_gateway.html#id ComputeExternalVpnGateway#id}
     *
     * @stability stable
     */
    readonly id?: number;
    /**
     * IP address of the interface in the external VPN gateway.
     *
     * Only IPv4 is supported. This IP address can be either from
     * your on-premise gateway or another Cloud provider's VPN gateway,
     * it cannot be an IP address from Google Compute Engine.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_external_vpn_gateway.html#ip_address ComputeExternalVpnGateway#ip_address}
     *
     * @stability stable
     */
    readonly ipAddress?: string;
}
/**
 * @stability stable
 */
export interface ComputeExternalVpnGatewayTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_external_vpn_gateway.html#create ComputeExternalVpnGateway#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/compute_external_vpn_gateway.html#delete ComputeExternalVpnGateway#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/google/r/compute_external_vpn_gateway.html google_compute_external_vpn_gateway}.
 *
 * @stability stable
 */
export declare class ComputeExternalVpnGateway extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/google/r/compute_external_vpn_gateway.html google_compute_external_vpn_gateway} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ComputeExternalVpnGatewayConfig);
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _redundancyType?;
    /**
     * @stability stable
     */
    get redundancyType(): string;
    /**
     * @stability stable
     */
    set redundancyType(value: string);
    /**
     * @stability stable
     */
    resetRedundancyType(): void;
    /**
     * @stability stable
     */
    get redundancyTypeInput(): string | undefined;
    /**
     * @stability stable
     */
    get selfLink(): string;
    private _interface?;
    /**
     * @stability stable
     */
    get interface(): ComputeExternalVpnGatewayInterface[];
    /**
     * @stability stable
     */
    set interface(value: ComputeExternalVpnGatewayInterface[]);
    /**
     * @stability stable
     */
    resetInterface(): void;
    /**
     * @stability stable
     */
    get interfaceInput(): ComputeExternalVpnGatewayInterface[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): ComputeExternalVpnGatewayTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: ComputeExternalVpnGatewayTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): ComputeExternalVpnGatewayTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
