import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface EventarcTriggerConfig extends cdktf.TerraformMetaArguments {
    /**
     * Optional. User labels attached to the triggers that can be used to group resources.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/eventarc_trigger.html#labels EventarcTrigger#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * The location for the resource.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/eventarc_trigger.html#location EventarcTrigger#location}
     *
     * @stability stable
     */
    readonly location: string;
    /**
     * Required.
     *
     * The resource name of the trigger. Must be unique within the location on the project and must be in `projects/{project}/locations/{location}/triggers/{trigger}` format.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/eventarc_trigger.html#name EventarcTrigger#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The project for the resource.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/eventarc_trigger.html#project EventarcTrigger#project}
     *
     * @stability stable
     */
    readonly project?: string;
    /**
     * Optional.
     *
     * The IAM service account email associated with the trigger. The service account represents the identity of the trigger. The principal who calls this API must have `iam.serviceAccounts.actAs` permission in the service account. See https://cloud.google.com/iam/docs/understanding-service-accounts?hl=en#sa_common for more information. For Cloud Run destinations, this service account is used to generate identity tokens when invoking the service. See https://cloud.google.com/run/docs/triggering/pubsub-push#create-service-account for information on how to invoke authenticated Cloud Run services. In order to create Audit Log triggers, the service account should also have `roles/eventarc.eventReceiver` IAM role.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/eventarc_trigger.html#service_account EventarcTrigger#service_account}
     *
     * @stability stable
     */
    readonly serviceAccount?: string;
    /**
     * destination block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/eventarc_trigger.html#destination EventarcTrigger#destination}
     *
     * @stability stable
     */
    readonly destination: EventarcTriggerDestination[];
    /**
     * matching_criteria block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/eventarc_trigger.html#matching_criteria EventarcTrigger#matching_criteria}
     *
     * @stability stable
     */
    readonly matchingCriteria: EventarcTriggerMatchingCriteria[];
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/eventarc_trigger.html#timeouts EventarcTrigger#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: EventarcTriggerTimeouts;
    /**
     * transport block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/eventarc_trigger.html#transport EventarcTrigger#transport}
     *
     * @stability stable
     */
    readonly transport?: EventarcTriggerTransport[];
}
/**
 * @stability stable
 */
export interface EventarcTriggerDestinationCloudRunService {
    /**
     * Optional.
     *
     * The relative path on the Cloud Run service the events should be sent to. The value must conform to the definition of URI path segment (section 3.3 of RFC2396). Examples: "/route", "route", "route/subroute".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/eventarc_trigger.html#path EventarcTrigger#path}
     *
     * @stability stable
     */
    readonly path?: string;
    /**
     * Required. The region the Cloud Run service is deployed in.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/eventarc_trigger.html#region EventarcTrigger#region}
     *
     * @stability stable
     */
    readonly region?: string;
    /**
     * Required.
     *
     * The name of the Cloud Run service being addressed. See https://cloud.google.com/run/docs/reference/rest/v1/namespaces.services. Only services located in the same project of the trigger object can be addressed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/eventarc_trigger.html#service EventarcTrigger#service}
     *
     * @stability stable
     */
    readonly service: string;
}
/**
 * @stability stable
 */
export interface EventarcTriggerDestination {
    /**
     * The Cloud Function resource name. Only Cloud Functions V2 is supported. Format: projects/{project}/locations/{location}/functions/{function}.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/eventarc_trigger.html#cloud_function EventarcTrigger#cloud_function}
     *
     * @stability stable
     */
    readonly cloudFunction?: string;
    /**
     * cloud_run_service block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/eventarc_trigger.html#cloud_run_service EventarcTrigger#cloud_run_service}
     *
     * @stability stable
     */
    readonly cloudRunService?: EventarcTriggerDestinationCloudRunService[];
}
/**
 * @stability stable
 */
export interface EventarcTriggerMatchingCriteria {
    /**
     * Required.
     *
     * The name of a CloudEvents attribute. Currently, only a subset of attributes are supported for filtering. All triggers MUST provide a filter for the 'type' attribute.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/eventarc_trigger.html#attribute EventarcTrigger#attribute}
     *
     * @stability stable
     */
    readonly attribute: string;
    /**
     * Required. The value for the attribute.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/eventarc_trigger.html#value EventarcTrigger#value}
     *
     * @stability stable
     */
    readonly value: string;
}
/**
 * @stability stable
 */
export interface EventarcTriggerTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/eventarc_trigger.html#create EventarcTrigger#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/eventarc_trigger.html#delete EventarcTrigger#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/eventarc_trigger.html#update EventarcTrigger#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export interface EventarcTriggerTransportPubsub {
    /**
     * Optional.
     *
     * The name of the Pub/Sub topic created and managed by Eventarc system as a transport for the event delivery. Format: `projects/{PROJECT_ID}/topics/{TOPIC_NAME}`. You may set an existing topic for triggers of the type `google.cloud.pubsub.topic.v1.messagePublished` only. The topic you provide here will not be deleted by Eventarc at trigger deletion.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/eventarc_trigger.html#topic EventarcTrigger#topic}
     *
     * @stability stable
     */
    readonly topic?: string;
}
/**
 * @stability stable
 */
export interface EventarcTriggerTransport {
    /**
     * pubsub block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/eventarc_trigger.html#pubsub EventarcTrigger#pubsub}
     *
     * @stability stable
     */
    readonly pubsub?: EventarcTriggerTransportPubsub[];
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/google/r/eventarc_trigger.html google_eventarc_trigger}.
 *
 * @stability stable
 */
export declare class EventarcTrigger extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/google/r/eventarc_trigger.html google_eventarc_trigger} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: EventarcTriggerConfig);
    /**
     * @stability stable
     */
    get createTime(): string;
    /**
     * @stability stable
     */
    get etag(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _serviceAccount?;
    /**
     * @stability stable
     */
    get serviceAccount(): string;
    /**
     * @stability stable
     */
    set serviceAccount(value: string);
    /**
     * @stability stable
     */
    resetServiceAccount(): void;
    /**
     * @stability stable
     */
    get serviceAccountInput(): string | undefined;
    /**
     * @stability stable
     */
    get uid(): string;
    /**
     * @stability stable
     */
    get updateTime(): string;
    private _destination;
    /**
     * @stability stable
     */
    get destination(): EventarcTriggerDestination[];
    /**
     * @stability stable
     */
    set destination(value: EventarcTriggerDestination[]);
    /**
     * @stability stable
     */
    get destinationInput(): EventarcTriggerDestination[];
    private _matchingCriteria;
    /**
     * @stability stable
     */
    get matchingCriteria(): EventarcTriggerMatchingCriteria[];
    /**
     * @stability stable
     */
    set matchingCriteria(value: EventarcTriggerMatchingCriteria[]);
    /**
     * @stability stable
     */
    get matchingCriteriaInput(): EventarcTriggerMatchingCriteria[];
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): EventarcTriggerTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: EventarcTriggerTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): EventarcTriggerTimeouts | undefined;
    private _transport?;
    /**
     * @stability stable
     */
    get transport(): EventarcTriggerTransport[];
    /**
     * @stability stable
     */
    set transport(value: EventarcTriggerTransport[]);
    /**
     * @stability stable
     */
    resetTransport(): void;
    /**
     * @stability stable
     */
    get transportInput(): EventarcTriggerTransport[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
