import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface PrivatecaCertificateConfig extends cdktf.TerraformMetaArguments {
    /**
     * Certificate Authority name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#certificate_authority PrivatecaCertificate#certificate_authority}
     *
     * @stability stable
     */
    readonly certificateAuthority?: string;
    /**
     * The resource name for a CertificateTemplate used to issue this certificate, in the format 'projects/*\/locations/*\/certificateTemplates/*'.
     *
     * If this is specified,
     * the caller must have the necessary permission to use this template. If this is
     * omitted, no template will be used. This template must be in the same location
     * as the Certificate.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#certificate_template PrivatecaCertificate#certificate_template}
     *
     * @stability stable
     */
    readonly certificateTemplate?: string;
    /**
     * Labels with user-defined metadata to apply to this resource.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#labels PrivatecaCertificate#labels}
     *
     * @stability stable
     */
    readonly labels?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * The desired lifetime of the CA certificate.
     *
     * Used to create the "notBeforeTime" and
     * "notAfterTime" fields inside an X.509 certificate. A duration in seconds with up to nine
     * fractional digits, terminated by 's'. Example: "3.5s".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#lifetime PrivatecaCertificate#lifetime}
     *
     * @stability stable
     */
    readonly lifetime?: string;
    /**
     * Location of the Certificate. A full list of valid locations can be found by running 'gcloud privateca locations list'.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#location PrivatecaCertificate#location}
     *
     * @stability stable
     */
    readonly location: string;
    /**
     * The name for this Certificate.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#name PrivatecaCertificate#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Immutable. A pem-encoded X.509 certificate signing request (CSR).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#pem_csr PrivatecaCertificate#pem_csr}
     *
     * @stability stable
     */
    readonly pemCsr?: string;
    /**
     * The name of the CaPool this Certificate belongs to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#pool PrivatecaCertificate#pool}
     *
     * @stability stable
     */
    readonly pool: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#project PrivatecaCertificate#project}.
     *
     * @stability stable
     */
    readonly project?: string;
    /**
     * config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#config PrivatecaCertificate#config}
     *
     * @stability stable
     */
    readonly config?: PrivatecaCertificateConfigA[];
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#timeouts PrivatecaCertificate#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: PrivatecaCertificateTimeouts;
}
/**
 * @stability stable
 */
export declare class PrivatecaCertificateCertificateDescriptionAuthorityKeyId extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get keyId(): string;
}
/**
 * @stability stable
 */
export declare class PrivatecaCertificateCertificateDescriptionCertFingerprint extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get sha256Hash(): string;
}
/**
 * @stability stable
 */
export declare class PrivatecaCertificateCertificateDescriptionConfigValuesKeyUsageBaseKeyUsageKeyUsageOptions extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get certSign(): any;
    /**
     * @stability stable
     */
    get contentCommitment(): any;
    /**
     * @stability stable
     */
    get crlSign(): any;
    /**
     * @stability stable
     */
    get dataEncipherment(): any;
    /**
     * @stability stable
     */
    get decipherOnly(): any;
    /**
     * @stability stable
     */
    get digitalSignature(): any;
    /**
     * @stability stable
     */
    get encipherOnly(): any;
    /**
     * @stability stable
     */
    get keyAgreement(): any;
    /**
     * @stability stable
     */
    get keyEncipherment(): any;
}
/**
 * @stability stable
 */
export declare class PrivatecaCertificateCertificateDescriptionConfigValuesKeyUsageBaseKeyUsage extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get keyUsageOptions(): any;
}
/**
 * @stability stable
 */
export declare class PrivatecaCertificateCertificateDescriptionConfigValuesKeyUsageExtendedKeyUsage extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get clientAuth(): any;
    /**
     * @stability stable
     */
    get codeSigning(): any;
    /**
     * @stability stable
     */
    get emailProtection(): any;
    /**
     * @stability stable
     */
    get ocspSigning(): any;
    /**
     * @stability stable
     */
    get serverAuth(): any;
    /**
     * @stability stable
     */
    get timeStamping(): any;
}
/**
 * @stability stable
 */
export declare class PrivatecaCertificateCertificateDescriptionConfigValuesKeyUsageUnknownExtendedKeyUsagesObectId extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get objectIdPath(): any;
}
/**
 * @stability stable
 */
export declare class PrivatecaCertificateCertificateDescriptionConfigValuesKeyUsageUnknownExtendedKeyUsages extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get obectId(): any;
}
/**
 * @stability stable
 */
export declare class PrivatecaCertificateCertificateDescriptionConfigValuesKeyUsage extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get baseKeyUsage(): any;
    /**
     * @stability stable
     */
    get extendedKeyUsage(): any;
    /**
     * @stability stable
     */
    get unknownExtendedKeyUsages(): any;
}
/**
 * @stability stable
 */
export declare class PrivatecaCertificateCertificateDescriptionConfigValues extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get keyUsage(): any;
}
/**
 * @stability stable
 */
export declare class PrivatecaCertificateCertificateDescriptionPublicKey extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get format(): string;
    /**
     * @stability stable
     */
    get key(): string;
}
/**
 * @stability stable
 */
export declare class PrivatecaCertificateCertificateDescriptionSubjectDescriptionSubject extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get commonName(): string;
    /**
     * @stability stable
     */
    get countryCode(): string;
    /**
     * @stability stable
     */
    get locality(): string;
    /**
     * @stability stable
     */
    get organization(): string;
    /**
     * @stability stable
     */
    get organizationalUnit(): string;
    /**
     * @stability stable
     */
    get postalCode(): string;
    /**
     * @stability stable
     */
    get province(): string;
    /**
     * @stability stable
     */
    get streetAddress(): string;
}
/**
 * @stability stable
 */
export declare class PrivatecaCertificateCertificateDescriptionSubjectDescriptionSubjectAltNameCustomSansObectId extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get objectIdPath(): any;
}
/**
 * @stability stable
 */
export declare class PrivatecaCertificateCertificateDescriptionSubjectDescriptionSubjectAltNameCustomSans extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get critical(): any;
    /**
     * @stability stable
     */
    get obectId(): any;
    /**
     * @stability stable
     */
    get value(): string;
}
/**
 * @stability stable
 */
export declare class PrivatecaCertificateCertificateDescriptionSubjectDescriptionSubjectAltName extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get customSans(): any;
    /**
     * @stability stable
     */
    get dnsNames(): string[];
    /**
     * @stability stable
     */
    get emailAddresses(): string[];
    /**
     * @stability stable
     */
    get ipAddresses(): string[];
    /**
     * @stability stable
     */
    get uris(): string[];
}
/**
 * @stability stable
 */
export declare class PrivatecaCertificateCertificateDescriptionSubjectDescription extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get hexSerialNumber(): string;
    /**
     * @stability stable
     */
    get lifetime(): string;
    /**
     * @stability stable
     */
    get notAfterTime(): string;
    /**
     * @stability stable
     */
    get notBeforeTime(): string;
    /**
     * @stability stable
     */
    get subject(): any;
    /**
     * @stability stable
     */
    get subjectAltName(): any;
}
/**
 * @stability stable
 */
export declare class PrivatecaCertificateCertificateDescriptionSubjectKeyId extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get keyId(): string;
}
/**
 * @stability stable
 */
export declare class PrivatecaCertificateCertificateDescription extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get aiaIssuingCertificateUrls(): string[];
    /**
     * @stability stable
     */
    get authorityKeyId(): any;
    /**
     * @stability stable
     */
    get certFingerprint(): any;
    /**
     * @stability stable
     */
    get configValues(): any;
    /**
     * @stability stable
     */
    get crlDistributionPoints(): string[];
    /**
     * @stability stable
     */
    get publicKey(): any;
    /**
     * @stability stable
     */
    get subjectDescription(): any;
    /**
     * @stability stable
     */
    get subjectKeyId(): any;
}
/**
 * @stability stable
 */
export declare class PrivatecaCertificateRevocationDetails extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get revocationState(): string;
    /**
     * @stability stable
     */
    get revocationTime(): string;
}
/**
 * @stability stable
 */
export interface PrivatecaCertificateConfigPublicKey {
    /**
     * The format of the public key. Currently, only PEM format is supported. Possible values: ["KEY_TYPE_UNSPECIFIED", "PEM"].
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#format PrivatecaCertificate#format}
     *
     * @stability stable
     */
    readonly format: string;
    /**
     * Required.
     *
     * A public key. When this is specified in a request, the padding and encoding can be any of the options described by the respective 'KeyType' value. When this is generated by the service, it will always be an RFC 5280 SubjectPublicKeyInfo structure containing an algorithm identifier and a key. A base64-encoded string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#key PrivatecaCertificate#key}
     *
     * @stability stable
     */
    readonly key?: string;
}
/**
 * @stability stable
 */
export interface PrivatecaCertificateConfigSubjectConfigSubject {
    /**
     * The common name of the distinguished name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#common_name PrivatecaCertificate#common_name}
     *
     * @stability stable
     */
    readonly commonName: string;
    /**
     * The country code of the subject.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#country_code PrivatecaCertificate#country_code}
     *
     * @stability stable
     */
    readonly countryCode?: string;
    /**
     * The locality or city of the subject.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#locality PrivatecaCertificate#locality}
     *
     * @stability stable
     */
    readonly locality?: string;
    /**
     * The organization of the subject.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#organization PrivatecaCertificate#organization}
     *
     * @stability stable
     */
    readonly organization: string;
    /**
     * The organizational unit of the subject.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#organizational_unit PrivatecaCertificate#organizational_unit}
     *
     * @stability stable
     */
    readonly organizationalUnit?: string;
    /**
     * The postal code of the subject.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#postal_code PrivatecaCertificate#postal_code}
     *
     * @stability stable
     */
    readonly postalCode?: string;
    /**
     * The province, territory, or regional state of the subject.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#province PrivatecaCertificate#province}
     *
     * @stability stable
     */
    readonly province?: string;
    /**
     * The street address of the subject.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#street_address PrivatecaCertificate#street_address}
     *
     * @stability stable
     */
    readonly streetAddress?: string;
}
/**
 * @stability stable
 */
export interface PrivatecaCertificateConfigSubjectConfigSubjectAltName {
    /**
     * Contains only valid, fully-qualified host names.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#dns_names PrivatecaCertificate#dns_names}
     *
     * @stability stable
     */
    readonly dnsNames?: string[];
    /**
     * Contains only valid RFC 2822 E-mail addresses.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#email_addresses PrivatecaCertificate#email_addresses}
     *
     * @stability stable
     */
    readonly emailAddresses?: string[];
    /**
     * Contains only valid 32-bit IPv4 addresses or RFC 4291 IPv6 addresses.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#ip_addresses PrivatecaCertificate#ip_addresses}
     *
     * @stability stable
     */
    readonly ipAddresses?: string[];
    /**
     * Contains only valid RFC 3986 URIs.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#uris PrivatecaCertificate#uris}
     *
     * @stability stable
     */
    readonly uris?: string[];
}
/**
 * @stability stable
 */
export interface PrivatecaCertificateConfigSubjectConfig {
    /**
     * subject block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#subject PrivatecaCertificate#subject}
     *
     * @stability stable
     */
    readonly subject: PrivatecaCertificateConfigSubjectConfigSubject[];
    /**
     * subject_alt_name block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#subject_alt_name PrivatecaCertificate#subject_alt_name}
     *
     * @stability stable
     */
    readonly subjectAltName?: PrivatecaCertificateConfigSubjectConfigSubjectAltName[];
}
/**
 * @stability stable
 */
export interface PrivatecaCertificateConfigX509ConfigAdditionalExtensionsObjectId {
    /**
     * An ObjectId specifies an object identifier (OID). These provide context and describe types in ASN.1 messages.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#object_id_path PrivatecaCertificate#object_id_path}
     *
     * @stability stable
     */
    readonly objectIdPath: number[];
}
/**
 * @stability stable
 */
export interface PrivatecaCertificateConfigX509ConfigAdditionalExtensions {
    /**
     * Indicates whether or not this extension is critical (i.e., if the client does not know how to handle this extension, the client should consider this to be an error).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#critical PrivatecaCertificate#critical}
     *
     * @stability stable
     */
    readonly critical: boolean | cdktf.IResolvable;
    /**
     * The value of this X.509 extension. A base64-encoded string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#value PrivatecaCertificate#value}
     *
     * @stability stable
     */
    readonly value: string;
    /**
     * object_id block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#object_id PrivatecaCertificate#object_id}
     *
     * @stability stable
     */
    readonly objectId: PrivatecaCertificateConfigX509ConfigAdditionalExtensionsObjectId[];
}
/**
 * @stability stable
 */
export interface PrivatecaCertificateConfigX509ConfigCaOptions {
    /**
     * Refers to the "CA" X.509 extension, which is a boolean value. When this value is missing, the extension will be omitted from the CA certificate.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#is_ca PrivatecaCertificate#is_ca}
     *
     * @stability stable
     */
    readonly isCa?: boolean | cdktf.IResolvable;
    /**
     * Refers to the path length restriction X.509 extension. For a CA certificate, this value describes the depth of subordinate CA certificates that are allowed. If this value is less than 0, the request will fail. If this value is missing, the max path length will be omitted from the CA certificate.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#max_issuer_path_length PrivatecaCertificate#max_issuer_path_length}
     *
     * @stability stable
     */
    readonly maxIssuerPathLength?: number;
}
/**
 * @stability stable
 */
export interface PrivatecaCertificateConfigX509ConfigKeyUsageBaseKeyUsage {
    /**
     * The key may be used to sign certificates.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#cert_sign PrivatecaCertificate#cert_sign}
     *
     * @stability stable
     */
    readonly certSign?: boolean | cdktf.IResolvable;
    /**
     * The key may be used for cryptographic commitments. Note that this may also be referred to as "non-repudiation".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#content_commitment PrivatecaCertificate#content_commitment}
     *
     * @stability stable
     */
    readonly contentCommitment?: boolean | cdktf.IResolvable;
    /**
     * The key may be used sign certificate revocation lists.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#crl_sign PrivatecaCertificate#crl_sign}
     *
     * @stability stable
     */
    readonly crlSign?: boolean | cdktf.IResolvable;
    /**
     * The key may be used to encipher data.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#data_encipherment PrivatecaCertificate#data_encipherment}
     *
     * @stability stable
     */
    readonly dataEncipherment?: boolean | cdktf.IResolvable;
    /**
     * The key may be used to decipher only.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#decipher_only PrivatecaCertificate#decipher_only}
     *
     * @stability stable
     */
    readonly decipherOnly?: boolean | cdktf.IResolvable;
    /**
     * The key may be used for digital signatures.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#digital_signature PrivatecaCertificate#digital_signature}
     *
     * @stability stable
     */
    readonly digitalSignature?: boolean | cdktf.IResolvable;
    /**
     * The key may be used to encipher only.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#encipher_only PrivatecaCertificate#encipher_only}
     *
     * @stability stable
     */
    readonly encipherOnly?: boolean | cdktf.IResolvable;
    /**
     * The key may be used in a key agreement protocol.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#key_agreement PrivatecaCertificate#key_agreement}
     *
     * @stability stable
     */
    readonly keyAgreement?: boolean | cdktf.IResolvable;
    /**
     * The key may be used to encipher other keys.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#key_encipherment PrivatecaCertificate#key_encipherment}
     *
     * @stability stable
     */
    readonly keyEncipherment?: boolean | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export interface PrivatecaCertificateConfigX509ConfigKeyUsageExtendedKeyUsage {
    /**
     * Corresponds to OID 1.3.6.1.5.5.7.3.2. Officially described as "TLS WWW client authentication", though regularly used for non-WWW TLS.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#client_auth PrivatecaCertificate#client_auth}
     *
     * @stability stable
     */
    readonly clientAuth?: boolean | cdktf.IResolvable;
    /**
     * Corresponds to OID 1.3.6.1.5.5.7.3.3. Officially described as "Signing of downloadable executable code client authentication".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#code_signing PrivatecaCertificate#code_signing}
     *
     * @stability stable
     */
    readonly codeSigning?: boolean | cdktf.IResolvable;
    /**
     * Corresponds to OID 1.3.6.1.5.5.7.3.4. Officially described as "Email protection".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#email_protection PrivatecaCertificate#email_protection}
     *
     * @stability stable
     */
    readonly emailProtection?: boolean | cdktf.IResolvable;
    /**
     * Corresponds to OID 1.3.6.1.5.5.7.3.9. Officially described as "Signing OCSP responses".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#ocsp_signing PrivatecaCertificate#ocsp_signing}
     *
     * @stability stable
     */
    readonly ocspSigning?: boolean | cdktf.IResolvable;
    /**
     * Corresponds to OID 1.3.6.1.5.5.7.3.1. Officially described as "TLS WWW server authentication", though regularly used for non-WWW TLS.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#server_auth PrivatecaCertificate#server_auth}
     *
     * @stability stable
     */
    readonly serverAuth?: boolean | cdktf.IResolvable;
    /**
     * Corresponds to OID 1.3.6.1.5.5.7.3.8. Officially described as "Binding the hash of an object to a time".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#time_stamping PrivatecaCertificate#time_stamping}
     *
     * @stability stable
     */
    readonly timeStamping?: boolean | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export interface PrivatecaCertificateConfigX509ConfigKeyUsageUnknownExtendedKeyUsages {
    /**
     * An ObjectId specifies an object identifier (OID). These provide context and describe types in ASN.1 messages.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#object_id_path PrivatecaCertificate#object_id_path}
     *
     * @stability stable
     */
    readonly objectIdPath: number[];
}
/**
 * @stability stable
 */
export interface PrivatecaCertificateConfigX509ConfigKeyUsage {
    /**
     * base_key_usage block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#base_key_usage PrivatecaCertificate#base_key_usage}
     *
     * @stability stable
     */
    readonly baseKeyUsage: PrivatecaCertificateConfigX509ConfigKeyUsageBaseKeyUsage[];
    /**
     * extended_key_usage block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#extended_key_usage PrivatecaCertificate#extended_key_usage}
     *
     * @stability stable
     */
    readonly extendedKeyUsage: PrivatecaCertificateConfigX509ConfigKeyUsageExtendedKeyUsage[];
    /**
     * unknown_extended_key_usages block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#unknown_extended_key_usages PrivatecaCertificate#unknown_extended_key_usages}
     *
     * @stability stable
     */
    readonly unknownExtendedKeyUsages?: PrivatecaCertificateConfigX509ConfigKeyUsageUnknownExtendedKeyUsages[];
}
/**
 * @stability stable
 */
export interface PrivatecaCertificateConfigX509ConfigPolicyIds {
    /**
     * An ObjectId specifies an object identifier (OID). These provide context and describe types in ASN.1 messages.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#object_id_path PrivatecaCertificate#object_id_path}
     *
     * @stability stable
     */
    readonly objectIdPath: number[];
}
/**
 * @stability stable
 */
export interface PrivatecaCertificateConfigX509Config {
    /**
     * Describes Online Certificate Status Protocol (OCSP) endpoint addresses that appear in the "Authority Information Access" extension in the certificate.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#aia_ocsp_servers PrivatecaCertificate#aia_ocsp_servers}
     *
     * @stability stable
     */
    readonly aiaOcspServers?: string[];
    /**
     * additional_extensions block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#additional_extensions PrivatecaCertificate#additional_extensions}
     *
     * @stability stable
     */
    readonly additionalExtensions?: PrivatecaCertificateConfigX509ConfigAdditionalExtensions[];
    /**
     * ca_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#ca_options PrivatecaCertificate#ca_options}
     *
     * @stability stable
     */
    readonly caOptions?: PrivatecaCertificateConfigX509ConfigCaOptions[];
    /**
     * key_usage block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#key_usage PrivatecaCertificate#key_usage}
     *
     * @stability stable
     */
    readonly keyUsage: PrivatecaCertificateConfigX509ConfigKeyUsage[];
    /**
     * policy_ids block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#policy_ids PrivatecaCertificate#policy_ids}
     *
     * @stability stable
     */
    readonly policyIds?: PrivatecaCertificateConfigX509ConfigPolicyIds[];
}
/**
 * @stability stable
 */
export interface PrivatecaCertificateConfigA {
    /**
     * public_key block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#public_key PrivatecaCertificate#public_key}
     *
     * @stability stable
     */
    readonly publicKey: PrivatecaCertificateConfigPublicKey[];
    /**
     * subject_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#subject_config PrivatecaCertificate#subject_config}
     *
     * @stability stable
     */
    readonly subjectConfig: PrivatecaCertificateConfigSubjectConfig[];
    /**
     * x509_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#x509_config PrivatecaCertificate#x509_config}
     *
     * @stability stable
     */
    readonly x509Config: PrivatecaCertificateConfigX509Config[];
}
/**
 * @stability stable
 */
export interface PrivatecaCertificateTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#create PrivatecaCertificate#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html#delete PrivatecaCertificate#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html google_privateca_certificate}.
 *
 * @stability stable
 */
export declare class PrivatecaCertificate extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/google/r/privateca_certificate.html google_privateca_certificate} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: PrivatecaCertificateConfig);
    private _certificateAuthority?;
    /**
     * @stability stable
     */
    get certificateAuthority(): string;
    /**
     * @stability stable
     */
    set certificateAuthority(value: string);
    /**
     * @stability stable
     */
    resetCertificateAuthority(): void;
    /**
     * @stability stable
     */
    get certificateAuthorityInput(): string | undefined;
    /**
     * @stability stable
     */
    certificateDescription(index: string): PrivatecaCertificateCertificateDescription;
    private _certificateTemplate?;
    /**
     * @stability stable
     */
    get certificateTemplate(): string;
    /**
     * @stability stable
     */
    set certificateTemplate(value: string);
    /**
     * @stability stable
     */
    resetCertificateTemplate(): void;
    /**
     * @stability stable
     */
    get certificateTemplateInput(): string | undefined;
    /**
     * @stability stable
     */
    get createTime(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set labels(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _lifetime?;
    /**
     * @stability stable
     */
    get lifetime(): string;
    /**
     * @stability stable
     */
    set lifetime(value: string);
    /**
     * @stability stable
     */
    resetLifetime(): void;
    /**
     * @stability stable
     */
    get lifetimeInput(): string | undefined;
    private _location;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    /**
     * @stability stable
     */
    get pemCertificate(): string;
    /**
     * @stability stable
     */
    get pemCertificates(): string[];
    private _pemCsr?;
    /**
     * @stability stable
     */
    get pemCsr(): string;
    /**
     * @stability stable
     */
    set pemCsr(value: string);
    /**
     * @stability stable
     */
    resetPemCsr(): void;
    /**
     * @stability stable
     */
    get pemCsrInput(): string | undefined;
    private _pool;
    /**
     * @stability stable
     */
    get pool(): string;
    /**
     * @stability stable
     */
    set pool(value: string);
    /**
     * @stability stable
     */
    get poolInput(): string;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    /**
     * @stability stable
     */
    revocationDetails(index: string): PrivatecaCertificateRevocationDetails;
    /**
     * @stability stable
     */
    get updateTime(): string;
    private _config?;
    /**
     * @stability stable
     */
    get config(): PrivatecaCertificateConfigA[];
    /**
     * @stability stable
     */
    set config(value: PrivatecaCertificateConfigA[]);
    /**
     * @stability stable
     */
    resetConfig(): void;
    /**
     * @stability stable
     */
    get configInput(): PrivatecaCertificateConfigA[] | undefined;
    private _timeouts?;
    /**
     * @stability stable
     */
    get timeouts(): PrivatecaCertificateTimeouts;
    /**
     * @stability stable
     */
    set timeouts(value: PrivatecaCertificateTimeouts);
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): PrivatecaCertificateTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
